/*
 * Java INI Package
 * Copyright (C) 2008 David Lewis
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public Licence as published by the Free
 * Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public Licence for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * <p>This package provides support for programmers to create, read and write
 * INI files in Java. INI files, also called property or configuration files,
 * are text files that store settings or data for applications.</p>
 * 
 * <p>INI files, contain 1 or more <strong>items</strong>, which is a line or
 * text consisting of a <strong>name</strong>, followed by an <strong>equals
 * symbol</strong>, followed by a <strong>value</strong>. For example:<br>
 * <pre>username = Smith</pre></p>
 *
 * <p>Items in an INI file can also be grouped together into sections. This
 * provides some organisation to the INI file, and also means that more than one
 * item can have the same name. The latter is allowed as item need to only have
 * a unique name within a section, not the entire INI file.</p>
 * 
 * </p>Comments are also allowed in an INI file, and are marked by a semi-colon
 * symbol. There is no need to place a &quot;close comment&quot; symbol after
 * the comment, as INI files only support <strong>end line</strong> comments,
 * which begin after the semi-colon symbol, and continue to the end of the
 * line.</p>
 * 
 * <p>The following is an example of the contents of an INI file storing an
 * application's last used settings:</p>
 * <p>
 * <pre>
 * [application_settings]
 * x = 20
 * y = 87
 * width = 800
 * height = 600
 * last_file = C:\temp\collection.7z
 * 
 * [statistics]
 * date_last = 06/10/2008    ; the date the application was last used
 * total_usage = 241         ; the number of times the application has been used
 * date_installed = 21/04/2008
 * </pre>
 * </p>
 * 
 * @author David Lewis
 * @version 1.0.0
 * @since 0.1.10
 */
package org.dtools.ini;